@@ -252,10 +252,12 @@ void ClassAd::
 Clear( )
 {
 	Unchain();
-	AttrList::iterator	itr;
-	for( itr = attrList.begin( ); itr != attrList.end( ); itr++ ) {
-		if( itr->second ) delete itr->second;
-	}
+#ifndef USE_CLASSAD_FLAT_MAP
+	AttrList::iterator      itr;
+    for( itr = attrList.begin( ); itr != attrList.end( ); itr++ ) {
+          if( itr->second ) delete itr->second;
+    }
+#endif
 	attrList.clear( );
 }
 
@@ -794,7 +796,9 @@ Delete( const string &name )
     deleted_attribute = false;
 	AttrList::iterator itr = attrList.find( name );
 	if( itr != attrList.end( ) ) {
+#ifndef USE_CLASSAD_FLAT_MAP
 		delete itr->second;
+#endif
 		attrList.erase( itr );
 		deleted_attribute = true;
 	}
@@ -843,6 +847,7 @@ Remove( const string &name )
 	AttrList::iterator itr = attrList.find( name );
 	if( itr != attrList.end( ) ) {
 		tree = itr->second;
+		itr->second = nullptr;
 		attrList.erase( itr );
 		tree->SetParentScope( NULL );
 	}
@@ -2141,7 +2146,9 @@ bool ClassAd::PruneChildAttr(const std::string & attrName, bool if_child_matches
 	}
 
 	if (prune_it) {
+#ifndef USE_CLASSAD_FLAT_MAP
 		delete itr->second;
+#endif
 		attrList.erase(itr);
 		return true;
 	}
@@ -2158,22 +2165,28 @@ int ClassAd::PruneChildAd()
 		AttrList::const_iterator	itr= attrList.begin( );
 		ExprTree 					*tree;
 	
+		std::list<std::string> victims;
+
 		while (itr != attrList.end() )
 		{
 			tree = chained_parent_ad->Lookup(itr->first);
 				
 			if(  tree && tree->SameAs(itr->second) ) {
-				AttrList::const_iterator rm_itr = itr;
-				itr++; // once 
-				// 1st remove from dirty list
-				MarkAttributeClean(rm_itr->first);
-				delete rm_itr->second;
-				attrList.erase( rm_itr->first );
+				MarkAttributeClean(itr->first);
+				victims.push_back(itr->first);
 				iRet++;
 			}
-			else
-			{
-				itr++;
+
+			itr++;
+		}
+
+		for (auto &s: victims) {
+			AttrList::iterator itr = attrList.find(s);
+			if( itr != attrList.end( ) ) {
+#ifndef USE_CLASSAD_FLAT_MAP
+				delete itr->second;
+#endif
+				attrList.erase( itr );
 			}
 		}
 	}
