@@ -388,7 +388,7 @@ walkHashTable (AdTypes adType, int (*scanFunction)(CollectorRecord *))
 	CollectorHashTable *table;
 	CollectorEngine::HashFunc func;
 	if (!LookupByAdType(adType, table, func)) {
-		dprintf (D_ALWAYS, "Unknown type %d\n", adType);
+		dprintf (D_ALWAYS, "Unknown type %ld\n", adType);
 		return 0;
 	}
 
@@ -1214,11 +1214,12 @@ extern bool   last_updateClassAd_was_insert;
 void
 movePrivateAttrs(ClassAd& dest, ClassAd& src)
 {
-	for (auto itr = src.begin(); itr != src.end(); /* no increment */ ) {
+	auto itr = src.begin();
+	while (itr != src.end()) {
 		if (ClassAdAttributeIsPrivateAny(itr->first)) {
-			const std::string name = itr->first;
-			ExprTree* expr = src.Remove((itr++)->first);
-			dest.Insert(name, expr);
+			const std::string &name = itr->first;
+			dest.Insert(name, itr->second->Copy());
+			itr = src.erase(itr);
 		} else {
 			itr++;
 		}
