@@ -22,6 +22,7 @@
 #include "condor_debug.h"
 #include "condor_config.h"
 #include "condor_ver_info.h"
+#include "condor_version.h"
 #include "condor_open.h"
 
 #include "daemon.h"
@@ -43,8 +44,6 @@
 
 #include "ipv6_hostname.h"
 
-#include <sstream>
-
 void
 Daemon::common_init() {
 	_type = DT_NONE;
@@ -243,6 +242,63 @@ Daemon::~Daemon()
 // Data-providing methods
 //////////////////////////////////////////////////////////////////////
 
+ClassAd *
+Daemon::locationAd() {
+	if( m_daemon_ad_ptr ) {
+		// dprintf( D_ALWAYS, "locationAd(): found daemon ad, returning it\n" );
+		return m_daemon_ad_ptr;
+	}
+
+	if( m_location_ad_ptr ) {
+		// dprintf( D_ALWAYS, "locationAd(): found location ad, returning it\n" );
+		return m_location_ad_ptr;
+	}
+
+	ClassAd * locationAd = new ClassAd();
+	const char * buffer = NULL;
+
+	buffer = this->addr();
+	if(! buffer) { goto failure; }
+	if(! locationAd->InsertAttr(ATTR_MY_ADDRESS, buffer)) { goto failure; }
+
+	buffer = this->name();
+	if(! buffer) { buffer = "Unknown"; }
+	if(! locationAd->InsertAttr(ATTR_NAME, buffer)) { goto failure; }
+
+	buffer = this->fullHostname();
+	if(! buffer) { buffer = "Unknown"; }
+	if(! locationAd->InsertAttr(ATTR_MACHINE, buffer)) { goto failure; }
+
+	/* This will inevitably be overwritten by CondorVersion(), below,
+	   so I don't know what the original was attempting accomplish here. */
+	buffer = this->version();
+	if(! buffer) { buffer = ""; }
+	if(! locationAd->InsertAttr(ATTR_VERSION, buffer)) { goto failure; }
+
+	AdTypes ad_type;
+	if(! convert_daemon_type_to_ad_type(this->type(), ad_type)) { goto failure; }
+	buffer = AdTypeToString(ad_type);
+	if(! buffer) { goto failure; }
+	if(! locationAd->InsertAttr(ATTR_MY_TYPE, buffer)) { goto failure; }
+
+	buffer = CondorVersion();
+	if(! locationAd->InsertAttr(ATTR_VERSION, buffer)) { goto failure; }
+
+	buffer = CondorPlatform();
+	if(! locationAd->InsertAttr(ATTR_PLATFORM, buffer)) { goto failure; }
+
+	// dprintf( D_ALWAYS, "locationAd(): synthesized location ad, returning it.\n" );
+	m_location_ad_ptr = locationAd;
+	return m_location_ad_ptr;
+
+  failure:;
+	// dprintf( D_ALWAYS, "Daemon::locationAd() failed.\n" );
+	delete locationAd;
+	return NULL;
+}
+
+
+
 const char*
 Daemon::name( void )
 {
@@ -2368,12 +2424,9 @@ Daemon::getSessionToken( const std::vector<std::string> &authz_bounding_limit, i
 	}
 
 	classad::ClassAd ad;
-	std::stringstream ss;
-	for (const auto &authz : authz_bounding_limit) {
-		ss << authz << ",";
-	}
-	const std::string &authz_limit_str = ss.str();
-	if (!authz_limit_str.empty() && !ad.InsertAttr(ATTR_SEC_LIMIT_AUTHORIZATION, authz_limit_str.substr(0, authz_limit_str.size()-1))) {
+
+	const std::string authz_limit_str = join(authz_bounding_limit, ",");
+	if (!authz_limit_str.empty() && !ad.InsertAttr(ATTR_SEC_LIMIT_AUTHORIZATION, authz_limit_str)) {
 		if (err) err->pushf("DAEMON", 1, "Failed to create token request ClassAd");
 		dprintf(D_FULLDEBUG, "Failed to create token request ClassAd\n");
 		return false;
@@ -2564,14 +2617,10 @@ Daemon::startTokenRequest( const std::string &identity,
 	}
 
 	classad::ClassAd ad;
-	std::stringstream ss;
-	for (const auto &authz : authz_bounding_set) {
-		ss << authz << ",";
-	}
-	const std::string &authz_limit_str = ss.str();
+	const std::string authz_limit_str = join(authz_bounding_set, ",");
+
 	if (!authz_limit_str.empty() &&
-		!ad.InsertAttr(ATTR_SEC_LIMIT_AUTHORIZATION,
-			authz_limit_str.substr(0, authz_limit_str.size()-1)))
+		!ad.InsertAttr(ATTR_SEC_LIMIT_AUTHORIZATION, authz_limit_str))
 	{
 		if (err) { err->pushf("DAEMON", 1, "Failed to create token request ClassAd"); }
 		dprintf(D_FULLDEBUG, "Failed to create token request ClassAd\n");
