@@ -113,6 +113,7 @@
 #define ATTR_CONDOR_ADMIN				"CondorAdmin"
 #define ATTR_CONSOLE_IDLE  "ConsoleIdle"
 #define ATTR_CONTAINER_IMAGE "ContainerImage"
+#define ATTR_CONTAINER_IMAGE_SOURCE "ContainerImageSource"
 #define ATTR_CONTINUE  "Continue"
 #define ATTR_CONTINUE_REASON  "ContinueReason"
 #define ATTR_CORE_SIZE  "CoreSize"
@@ -439,6 +440,8 @@
 #define ATTR_JOB_STATE  "JobState"
 #define ATTR_JOB_STATUS  "JobStatus"
 #define ATTR_LAST_JOB_STATUS  "LastJobStatus"
+#define ATTR_JOB_STARTER_DEBUG "JobStarterDebug"
+#define ATTR_JOB_STARTER_LOG "JobStarterLog"
 #define ATTR_JOB_TOE "ToE"  // termination of execution ad
 #define ATTR_JOB_STATUS_ON_RELEASE  "JobStatusOnRelease"
 #define ATTR_JOB_SUBMIT_METHOD "JobSubmitMethod"
@@ -791,6 +794,11 @@
 #define ATTR_UPDATE_SEQUENCE_NUMBER  "UpdateSequenceNumber"
 #define ATTR_USE_PARROT  "UseParrot"
 #define ATTR_USER  "User"
+#define ATTR_USERREC_OPT_prefix "_userrec_opt_"
+#define ATTR_USERREC_OPT_CREATE "_userrec_opt_create"
+#define ATTR_USERREC_OPT_UPDATE "_userrec_opt_update"
+#define ATTR_USERREC_OPT_ME "_userrec_opt_me"
+#define ATTR_USERREC_OPT_CREATE_DEPRECATED "create"
 #define ATTR_VACATE  "Vacate"
 #define ATTR_VACATE_TYPE  "VacateType"
 #define ATTR_VIRTUAL_MEMORY  "VirtualMemory"
