@@ -40,7 +40,9 @@
 #include <algorithm>
 
 #include "spooled_job_files.h"
+#include "job_ad_instance_recording.h"
 
+#define SANDBOX_STARTER_LOG_FILENAME ".starter.log"
 extern const char* public_schedd_addr;	// in shadow_v61_main.C
 
 // for remote syscalls, this is currently in NTreceivers.C.
@@ -1362,6 +1364,24 @@ RemoteResource::updateFromStarter( ClassAd* update_ad )
 		jobAd->Assign(ATTR_JOB_CORE_DUMPED, bool_value);
 	}
 
+
+	std::string PluginResultList = "PluginResultList";
+	std::array< std::string, 3 > prefixes( { "Input", "Checkpoint", "Output" } );
+	for( const auto & prefix : prefixes ) {
+		std::string attributeName = prefix + PluginResultList;
+		ExprTree * resultList = update_ad->LookupExpr( attributeName );
+		if( resultList != NULL ) {
+			classad::ClassAd c;
+			// Arguably, the epoch log would be easier to parse if the
+			// attribute name were always PluginResultList.
+			c.Insert( attributeName, resultList );
+			writeJobEpochFile( jobAd, & c, as_upper_case(prefix).c_str() );
+			c.Remove( attributeName );
+			writeJobEpochFile( jobAd, starterAd, "STARTER" );
+		}
+	}
+
+
 		// The starter sends this attribute whether or not we are spooling
 		// output (because it doesn't know if we are).  Technically, we
 		// only need to write this attribute into the job ClassAd if we
@@ -2221,6 +2241,11 @@ RemoteResource::initFileTransfer()
 
 		filetrans.AddDownloadFilenameRemap( StderrRemapName, file.c_str() );
 	}
+	if ( jobAd->LookupString( ATTR_JOB_STARTER_LOG, file ) && 
+		 strcmp(file.c_str(), SANDBOX_STARTER_LOG_FILENAME )) {
+
+		filetrans.AddDownloadFilenameRemap(SANDBOX_STARTER_LOG_FILENAME, file.c_str());
+	}
 
 	//
 	// Check this job's SPOOL directory for MANIFEST files and pick the
