@@ -72,10 +72,19 @@ Returns KEEP_STREAM if the stream is still valid, ~KEEP_STREAM otherwise.
 
 int IOProxyHandler::handle_request( Stream *s )
 {
-	char line[CHIRP_LINE_MAX];
+	char line[CHIRP_LINE_MAX+1];
 	ReliSock *r = (ReliSock *) s;
 
-	if(r->get_line_raw(line,CHIRP_LINE_MAX)>0)  {
+	int bytes = r->get_line_raw(line, CHIRP_LINE_MAX+1);
+	if (bytes > CHIRP_LINE_MAX) {
+		// request too big
+		dprintf(D_ALWAYS, "IOProxyHandler: rejecting chirp request because it is too large\n");
+		snprintf(line,CHIRP_LINE_MAX,"%d",CHIRP_ERROR_TOO_BIG);
+		r->put_line_raw(line);
+		delete this;
+		return ~KEEP_STREAM;
+	}
+	if(bytes > 0)  {
 		if( got_cookie ) {
 			handle_standard_request(r,line);
 		} else {
