@@ -598,6 +598,30 @@ sysapi_get_linux_info(void)
 	}
 	}
 	
+    // For now get the pretty name for the info string from /etc/os-release
+    // This is a minimal change for LTS
+    // In the future, just process /etc/os-release
+    if (!info_str) {
+        my_fp = safe_fopen_wrapper_follow("/etc/os-release", "r");
+        if ( my_fp != NULL ) {
+            char tmp_str[200] = {0};
+            while (fgets(tmp_str, sizeof(tmp_str), my_fp)) {
+                if (strstr(tmp_str, "PRETTY_NAME")) {
+                    dprintf(D_FULLDEBUG, "Pretty name /etc/os-release:  %s \n", tmp_str);
+                    if (char *open_quote = strchr(tmp_str, '"')) {
+                        char *pretty_name = open_quote + 1;
+                        if (char* close_quote = strchr(pretty_name, '"')) {
+                            *close_quote = 0;
+                        }
+                        info_str = strdup( pretty_name );
+                        break;
+                    }
+                }
+            }
+            fclose(my_fp);
+        }
+    }
+
 	if (!info_str) {
 		info_str = strdup( "Unknown" );
 	}
