@@ -178,6 +178,12 @@ int DockerAPI::createContainer(
 		// Add a label to mark this container as htcondor-managed
 	runArgs.AppendArg(HTCondorLabel);
 
+	// We never need stdout/err to go to the docker logs, we will write our own stdout
+	if (param_boolean("DOCKER_LOG_DRIVER_NONE", true)) {
+		runArgs.AppendArg("--log-driver");
+		runArgs.AppendArg("none");
+	}
+
 	if ( ! add_env_to_args_for_docker(runArgs, env)) {
 		dprintf( D_ALWAYS, "Failed to pass enviroment to docker.\n" );
 		return -8;
@@ -1234,6 +1240,7 @@ static bool add_docker_arg(ArgList &runArgs) {
 		dprintf( D_ALWAYS, "DOCKER is undefined.\n" );
 		return false;
 	}
+
 	const char * pdocker = docker.c_str();
 	if (starts_with(docker, "sudo ")) {
 		runArgs.AppendArg("/usr/bin/sudo");
@@ -1244,6 +1251,16 @@ static bool add_docker_arg(ArgList &runArgs) {
 			return false;
 		}
 	}
+
+	// Avoid startd log spam by checking if the docker binary
+	// exists, and not try to run docker info, etc. if the binary
+	// isn't there.
+	struct stat buf;
+	int r = stat(pdocker, &buf);
+	if ((r < 0) && (errno == ENOENT)) {
+		return false;
+	}
+
 	runArgs.AppendArg(pdocker);
 	return true;
 }
