@@ -225,7 +225,7 @@ ProcFamilyDirectCgroupV1::cgroupify_process(const std::string &cgroup_name, pid_
 }
 
 bool 
-ProcFamilyDirectCgroupV1::track_family_via_cgroup(pid_t pid, const FamilyInfo *fi) {
+ProcFamilyDirectCgroupV1::track_family_via_cgroup(pid_t pid, FamilyInfo *fi) {
 
 	ASSERT(fi->cgroup);
 
@@ -238,7 +238,8 @@ ProcFamilyDirectCgroupV1::track_family_via_cgroup(pid_t pid, const FamilyInfo *f
 		ASSERT("Couldn't insert into cgroup map, duplicate?");
 	}
 
-	return cgroupify_process(cgroup_name, pid);
+	fi->cgroup_active = cgroupify_process(cgroup_name, pid);
+	return fi->cgroup_active;
 }
 
 #ifndef USER_HZ
