@@ -46,7 +46,7 @@ static IOProcess ioprocess;
 // forwarding declaration
 static void gahp_output_return_error();
 static void gahp_output_return_success();
-static void gahp_output_return (const char ** results, const int count);
+static void gahp_output_return (const char ** results, size_t count);
 static int verify_gahp_command(char ** argv, int argc);
 static void *worker_function( void *ptr );
 
@@ -238,13 +238,13 @@ verify_gahp_command(char ** argv, int argc) {
 }
 
 void
-gahp_output_return (const char ** results, const int count) {
-	int i=0;
+gahp_output_return (const char ** results, size_t count) {
+	size_t i=0;
 	for (i=0; i<count; i++) {
-		printf ("%s", results[i]);
-		if (i < (count - 1 )) {
+		if (i > 0) {
 			printf (" ");
 		}
+		printf ("%s", results[i]);
 	}
 
 	printf ("\n");
@@ -379,17 +379,14 @@ IOProcess::stdinPipeHandler()
 				// Print each result line
 
 				// Print number of results
-				printf("%s %d\n", GAHP_RESULT_SUCCESS, numOfResult());
+				printf("%s %zu\n", GAHP_RESULT_SUCCESS, m_result_list.size());
 				fflush(stdout);
 
-				startResultIteration();
-
-				char* next = NULL;
-				while ((next = NextResult()) != NULL) {
-					printf ("%s", next);
+				for (const auto& next : m_result_list) {
+					printf ("%s", next.c_str());
 					fflush(stdout);
-					deleteCurrentResult();
 				}
+				m_result_list.clear();
 				m_new_results_signaled = false;
 
 			} else if (strcasecmp (args.argv[0], GAHP_COMMAND_VERSION) == 0) {
@@ -408,14 +405,14 @@ IOProcess::stdinPipeHandler()
 				m_async_mode = false;
 				gahp_output_return_success();
 			} else if (strcasecmp (args.argv[0], GAHP_COMMAND_COMMANDS) == 0) {
-				StringList openstack_commands;
-				int num_commands = 0;
+				std::vector<std::string> openstack_commands;
+				size_t num_commands = 0;
 
 				num_commands = allOpenstackCommands(openstack_commands);
 				num_commands += 7;
 
 				const char *commands[num_commands];
-				int i = 0;
+				size_t i = 0;
 				commands[i++] = GAHP_RESULT_SUCCESS;
 				commands[i++] = GAHP_COMMAND_ASYNC_MODE_ON;
 				commands[i++] = GAHP_COMMAND_ASYNC_MODE_OFF;
@@ -424,11 +421,8 @@ IOProcess::stdinPipeHandler()
 				commands[i++] = GAHP_COMMAND_VERSION;
 				commands[i++] = GAHP_COMMAND_COMMANDS;
 
-				openstack_commands.rewind();
-				char *one_openstack_command = NULL;
-
-				while( (one_openstack_command = openstack_commands.next() ) != NULL ) {
-					commands[i++] = one_openstack_command;
+				for (const auto& one_command : openstack_commands) {
+					commands[i++] = one_command.c_str();
 				}
 
 				gahp_output_return (commands, i);
@@ -536,7 +530,7 @@ IOProcess::addResult(const char *result)
 	}
 
 	// Put this result into result buffer
-	m_result_list.append(result);
+	m_result_list.emplace_back(result);
 
 	if (m_async_mode) {
 		if (!m_new_results_signaled) {
